@@ -28,6 +28,7 @@ from django.core.urlresolvers import reverse
 from django import http
 from django import shortcuts
 from django.utils import decorators as django_dec
+from django.utils import html
 from django.utils import http as http_utils
 from django.utils.translation import ugettext_lazy as _
 from django.views.generic import list as list_view
@@ -45,7 +46,7 @@ from muranodashboard.dynamic_ui import helpers
 from muranodashboard.dynamic_ui import services
 from muranodashboard.environments import api as env_api
 from muranodashboard.environments import consts
-
+from muranodashboard.packages import consts as pkg_consts
 
 LOG = logging.getLogger(__name__)
 ALL_CATEGORY_NAME = 'All'
@@ -366,7 +367,9 @@ class Wizard(views.ModalFormMixin, LazyWizard):
         # that way until we move here from django Wizard to horizon workflow
         if views.ADD_TO_FIELD_HEADER in self.request.META:
             field_id = self.request.META[views.ADD_TO_FIELD_HEADER]
-            response = http.HttpResponse(json.dumps([obj_id, obj_name]))
+            response = http.HttpResponse(json.dumps(
+                [obj_id, html.escape(obj_name)]
+            ))
             response["X-Horizon-Add-To-Field"] = field_id
             return response
         else:
@@ -483,6 +486,7 @@ class IndexView(list_view.ListView):
         else:
             query_params = self.get_query_params(internal_query=True)
             query_params['sort_dir'] = 'asc'
+            query_params['catalog'] = True
             packages, more = pkg_api.package_list(
                 self.request, filters=query_params, paginate=True,
                 marker=self.get_marker(), page_size=1)
@@ -542,7 +546,11 @@ class IndexView(list_view.ListView):
 
         context['tenant_id'] = self.request.session['token'].tenant['id']
         context.update(get_environments_context(self.request))
-
+        context['repo_url'] = pkg_consts.MURANO_REPO_URL
+        context['pkg_def_url'] = reverse('horizon:murano:packages:index')
+        context['no_apps'] = True
+        if self.get_current_category() != ALL_CATEGORY_NAME or search:
+            context['no_apps'] = False
         return context
 
 
