@@ -24,6 +24,7 @@ from django import forms
 from django.http import Http404
 from django.template import defaultfilters
 from django.template import loader
+from django.utils import html
 from django.utils.translation import ugettext_lazy as _
 import floppyforms
 from horizon import exceptions
@@ -146,6 +147,9 @@ class RawProperty(object):
         return property(_get, _set, _del)
 
 
+FIELD_ARGS_TO_ESCAPE = ['help_text', 'initial', 'description', 'label']
+
+
 class CustomPropertiesField(forms.Field):
     def __init__(self, description=None, description_title=None,
                  *args, **kwargs):
@@ -153,6 +157,10 @@ class CustomPropertiesField(forms.Field):
         self.description_title = (description_title or
                                   unicode(kwargs.get('label', '')))
 
+        for arg in FIELD_ARGS_TO_ESCAPE:
+            if kwargs.get(arg):
+                kwargs[arg] = html.escape(unicode(kwargs[arg]))
+
         validators = []
         for validator in kwargs.get('validators', []):
             if hasattr(validator, '__call__'):  # single regexpValidator
@@ -558,6 +566,7 @@ class BooleanField(forms.BooleanField, CustomPropertiesField):
         else:
             widget = forms.CheckboxInput(attrs={'class': 'checkbox'})
         kwargs['widget'] = widget
+        kwargs['required'] = False
         super(BooleanField, self).__init__(*args, **kwargs)
 
 
@@ -717,7 +726,8 @@ def make_select_cls(fqns):
             self.widget.add_item_link = _make_link
             apps = env_api.service_list_by_fqns(request, environment_id, fqns)
             choices = [('', self.empty_value_message)]
-            choices.extend([(app['?']['id'], app.name) for app in apps])
+            choices.extend([(app['?']['id'],
+                             html.escape(app.name)) for app in apps])
             self.choices = choices
             # NOTE(tsufiev): streamline the drop-down UX: auto-select the
             # single available option in a drop-down
