@@ -13,11 +13,13 @@
 #    under the License.
 
 from collections import defaultdict
+import copy
+import logging
+import types
 
 from django import forms
-from django.utils.translation import gettext_lazy as _
-from oslo_log import log as logging
-from yaql import legacy
+from django.utils.translation import ugettext_lazy as _
+import yaql
 
 import muranodashboard.dynamic_ui.fields as fields
 import muranodashboard.dynamic_ui.helpers as helpers
@@ -42,23 +44,26 @@ TYPES.update({
     'password': fields.PasswordField,
     'integer': fields.IntegerField,
     'databaselist': fields.DatabaseListField,
+    'table': fields.TableField,
     'flavor': fields.FlavorChoiceField,
     'keypair': fields.KeyPairChoiceField,
     'image': fields.ImageChoiceField,
     'azone': fields.AZoneChoiceField,
-    'network': fields.NetworkChoiceField,
     'text': (fields.CharField, forms.Textarea),
     'choice': fields.ChoiceField,
-    'floatingip': fields.FloatingIpBooleanField,
-    'securitygroup': fields.SecurityGroupChoiceField,
-    'volume': fields.VolumeChoiceField,
-    'zone': fields.ZoneChoiceField,
+    'floatingip': fields.FloatingIpBooleanField
 })
 
+# From Horizon project/instances/workflow/create_instance
+KEYPAIR_IMPORT_URL = "horizon:project:access_and_security:keypairs:import"
+TYPES_KWARGS = {
+    'keypair': {'add_item_link': KEYPAIR_IMPORT_URL}
+}
+
 
 def _collect_fields(field_specs, form_name, service):
     def process_widget(cls, kwargs):
-        if isinstance(cls, tuple):
+        if isinstance(cls, types.TupleType):
             cls, _w = cls
             kwargs['widget'] = _w
 
@@ -68,7 +73,7 @@ def _collect_fields(field_specs, form_name, service):
             del kwargs['widget_media']
 
             class Widget(widget):
-                class Media(object):
+                class Media:
                     js = media.get('js', ())
                     css = media.get('css', {})
             widget = Widget
@@ -80,25 +85,25 @@ def _collect_fields(field_specs, form_name, service):
     def parse_spec(spec, keys=None):
         if keys is None:
             keys = []
-        if not isinstance(keys, list):
+        if not isinstance(keys, types.ListType):
             keys = [keys]
         key = keys and keys[-1] or None
 
         if isinstance(spec, yaql_expression.YaqlExpression):
             return key, fields.RawProperty(key, spec)
-        elif isinstance(spec, dict):
+        elif isinstance(spec, types.DictType):
             items = []
-            for k, v in spec.items():
+            for k, v in spec.iteritems():
                 k = helpers.decamelize(k)
                 new_key, v = parse_spec(v, keys + [k])
                 if new_key:
                     k = new_key
                 items.append((k, v))
             return key, dict(items)
-        elif isinstance(spec, list):
+        elif isinstance(spec, types.ListType):
             return key, [parse_spec(_spec, keys)[1] for _spec in spec]
-        elif isinstance(spec, str) and helpers.is_localizable(keys):
-            return key, spec
+        elif isinstance(spec, basestring) and helpers.is_localizable(keys):
+            return key, _(spec)
         else:
             if key == 'hidden':
                 if spec:
@@ -115,12 +120,13 @@ def _collect_fields(field_specs, form_name, service):
         if isinstance(_type, list):  # make list keys hashable for TYPES dict
             _type = tuple(_type)
         _ignorable, kwargs = parse_spec(field_spec)
+        kwargs.update(TYPES_KWARGS.get(_type, {}))
         cls, kwargs['widget'] = process_widget(TYPES[_type], kwargs)
         cls = cls.finalize_properties(kwargs, form_name, service)
 
         return name, cls(**kwargs)
 
-    return [make_field(_spec) for _spec in field_specs]
+    return [make_field(copy.deepcopy(_spec)) for _spec in field_specs]
 
 
 class DynamicFormMetaclass(forms.forms.DeclarativeFieldsMetaclass):
@@ -135,9 +141,7 @@ class DynamicFormMetaclass(forms.forms.DeclarativeFieldsMetaclass):
 
 
 class UpdatableFieldsForm(forms.Form):
-    """Dynamic updatable form
-
-    This class is supposed to be a base for forms belonging to a FormWizard
+    """This class is supposed to be a base for forms belonging to a FormWizard
     descendant, or be used as a mixin for workflows.Action class.
 
     In first case the `request' used in `update' method is provided in
@@ -153,20 +157,20 @@ class UpdatableFieldsForm(forms.Form):
         # collections.OrderedDict for Django >= 1.7
         updated_fields = self.fields.__class__()
 
-        for name, field in self.fields.items():
+        for name, field in self.fields.iteritems():
             updated_fields[name] = field
-            if isinstance(field, fields.PasswordField) and field.confirm_input:
-                if not field.has_clone and field.original:
-                    updated_fields[
-                        field.get_clone_name(name)] = field.clone_field()
+            if (isinstance(field, fields.PasswordField) and
+                    not field.has_clone and field.original):
+                updated_fields[
+                    field.get_clone_name(name)] = field.clone_field()
 
         self.fields = updated_fields
 
-        for name, field in self.fields.items():
+        for name, field in self.fields.iteritems():
             if hasattr(field, 'update'):
                 field.update(self.initial, form=self, request=request)
             if not field.required:
-                field.widget.attrs['placeholder'] = _('Optional')
+                field.widget.attrs['placeholder'] = 'Optional'
 
 
 class ServiceConfigurationForm(UpdatableFieldsForm):
@@ -175,19 +179,19 @@ class ServiceConfigurationForm(UpdatableFieldsForm):
         super(ServiceConfigurationForm, self).__init__(*args, **kwargs)
 
         self.auto_id = '{0}_%s'.format(self.initial.get('app_id'))
-        self.context = legacy.create_context()
+        self.context = yaql.create_context()
         yaql_functions.register(self.context)
 
         self.finalize_fields()
         self.update_fields()
 
     def finalize_fields(self):
-        for field_name, field in self.fields.items():
+        for field_name, field in self.fields.iteritems():
             field.form = self
 
             validators = []
             for v in field.validators:
-                expr = isinstance(v, dict) and v.get('expr')
+                expr = isinstance(v, types.DictType) and v.get('expr')
                 if expr and isinstance(expr, fields.RawProperty):
                     v = fields.make_yaql_validator(v)
                 validators.append(v)
@@ -204,23 +208,20 @@ class ServiceConfigurationForm(UpdatableFieldsForm):
             for validator in self.validators:
                 expr = validator['expr']
                 if not expr.evaluate(data=all_data, context=self.context):
-                    error_messages.append(validator.get('message',
-                                          _('Validation Error occurred')))
+                    error_messages.append(_(validator.get('message', '')))
             if error_messages:
                 raise forms.ValidationError(error_messages)
 
-            for name, field in self.fields.items():
+            for name, field in self.fields.iteritems():
                 if (isinstance(field, fields.PasswordField) and
-                        getattr(field, 'enabled', True) and
-                        field.confirm_input):
+                        getattr(field, 'enabled', True)):
                     field.compare(name, cleaned_data)
 
                 if hasattr(field, 'postclean'):
-                    value = field.postclean(self, name, cleaned_data)
+                    value = field.postclean(self, cleaned_data)
                     if value:
                         cleaned_data[name] = value
-                        LOG.debug("Update '%s' data in postclean method" %
-                                  name)
+                        LOG.debug("Update cleaned data in postclean method")
 
             self.service.update_cleaned_data(cleaned_data, form=self)
             return cleaned_data
