@@ -1,27 +1,10 @@
-/*    Copyright (c) 2013 Mirantis, Inc.
-
-    Licensed under the Apache License, Version 2.0 (the "License"); you may
-    not use this file except in compliance with the License. You may obtain
-    a copy of the License at
-
-         http://www.apache.org/licenses/LICENSE-2.0
-
-    Unless required by applicable law or agreed to in writing, software
-    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-    License for the specific language governing permissions and limitations
-    under the License.
-*/
 $(function() {
-  "use strict";
-
   horizon.tabs.addTabLoadFunction(initServicesTab);
   initServicesTab($('.tab-content .tab-pane.active'));
-
   function initServicesTab($tab) {
-    var $dropArea = $tab.find('.drop_component');
-    var draggedAppUrl = null;
-    var firstDropTarget = null;
+    var $dropArea = $tab.find('.drop_component'),
+      draggedAppUrl = null,
+      firstDropTarget = null;
 
     function bindAppTileHandlers() {
       $('.draggable_app').each(function () {
@@ -34,7 +17,7 @@ $(function() {
           ev.originalEvent.dataTransfer.setData('text/uri-list', draggedAppUrl);
         }).on('dragend', function () {
           $dropArea.removeClass('over');
-        });
+        })
       });
     }
 
@@ -55,11 +38,11 @@ $(function() {
       return false;
     });
     var packages = $.parseJSON($('#apps_carousel_contents').val());
-    function subdivide(array, numOfItems) {
-      var chunks = [];
-      var seq = array;
-      var head = seq.slice(0, numOfItems);
-      var tail = seq.slice(numOfItems);
+    function subdivide(numOfItems) {
+      var chunks = [],
+        seq = this,
+        head = seq.slice(0, numOfItems),
+        tail = seq.slice(numOfItems);
       while (tail.length) {
         chunks.push(head);
         head = tail.slice(0, numOfItems);
@@ -69,29 +52,21 @@ $(function() {
       return chunks;
     }
 
-    var $carouselInner = $tab.find('.carousel-inner');
-    var $carousel = $('#apps_carousel');
-    var $filter = $('#envAppsFilter').find('input');
-    var $noAppMsg = $('#no_apps_found_message');
-    var category = 'All';
-    var ALL_CATEGORY = 'All';
-    var filterValue = '';
-    var ENTER_KEYCODE = 13;
-    var tileTemplate,
-      environmentId;
-
-    var $appTitleSmall = $('#app_tile_small');
-    if ($appTitleSmall.length > 0) {
-      tileTemplate = Hogan.compile($appTitleSmall.html());
-    }
-    if ($('#environmentId').length > 0) {
+    Array.prototype.subdivide = subdivide;
+    var $carouselInner = $tab.find('.carousel-inner'),
+      $carousel = $('#apps_carousel'),
+      $filter = $('#envAppsFilter').find('input'),
+      $noAppMsg = $('#no_apps_found_message'),
+      category = ALL_CATEGORY = 'All',
+      filterValue = '',
+      ENTER_KEYCODE = 13;
+    var tileTemplate = Hogan.compile($('#app_tile_small').html()),
       environmentId = $('#environmentId').val();
-    }
 
     function fillCarousel(apps) {
       var i = apps.length;
       while (i--) {
-        if (TENANT_ID !== apps[i].owner_id && apps[i].is_public === false) {
+        if (tenant_id !== apps[i].owner_id && apps[i].is_public == false) {
           apps.splice(i, 1);
         }
       }
@@ -101,10 +76,10 @@ $(function() {
         if ($carousel.css('display') === 'none') {
           $carousel.show();
         }
-        subdivide(apps, 6).forEach(function (chunk, index) {
-          var $item = $('<div class="item"></div>');
-          var $row = $('<div class="row"></div>');
-          if (index === 0) {
+        apps.subdivide(6).forEach(function (chunk, index) {
+          var $item = $('<div class="item"></div>'),
+            $row = $('<div class="row"></div>');
+          if (index == 0) {
             $item.addClass('active');
           }
           $item.appendTo($row);
@@ -115,17 +90,17 @@ $(function() {
               app_id: pkg.id
             });
             // tenant_id is obtained from corresponding Django template
-            if (TENANT_ID === pkg.owner_id) {
+            if (tenant_id === pkg.owner_id) {
               html = $(html).find('img.ribbon').remove().end();
             }
             $(html).appendTo($item);
           });
           $item.appendTo($carouselInner);
         });
-        $('div.carousel-control').removeClass('item');
+        $('div.carousel-control').removeClass('item')
         bindAppTileHandlers();
       } else {
-        if ($('#no_apps_in_catalog_message').length === 0) {
+        if ($('#no_apps_in_catalog_message').length == 0) {
           $noAppMsg.show();
         }
         $carousel.hide();
@@ -143,11 +118,10 @@ $(function() {
       if (category === ALL_CATEGORY && filterValue === '') {
         fillCarousel(packages);
       } else {
-        var filterRegexp = new RegExp(filterValue, 'i');
-        var filterRegexpExact = new RegExp('\\b' + filterValue + '\\b', 'i');
+        var filterRegexp = new RegExp(filterValue, 'i'),
+          filterRegexpExact = new RegExp('\\b' + filterValue + '\\b', 'i');
         fillCarousel(packages.filter(function (pkg) {
-          var categorySatisfied = true;
-          var filterSatisfied = true;
+          var categorySatisfied = true, filterSatisfied = true;
           if (category !== ALL_CATEGORY) {
             categorySatisfied = pkg.categories.indexOf(category) > -1;
           }
@@ -159,21 +133,20 @@ $(function() {
             });
           }
           return categorySatisfied && filterSatisfied;
-        }));
+        }))
       }
     }
 
     // dynamic carousel refilling on category change
     $('#envAppsCategory').on('click', 'a', function (env) {
-      var $category = $(this);
-      category = $category.attr('data-category-name');
-      $('#envAppsCategoryName').text($category.text());
+      category = $(this).text();
+      $('#envAppsCategoryName').text(category);
       refillCarousel();
       env.preventDefault();
     });
     // dynamic carousel refilling on search box non-empty submission
     $filter.keypress(function (ev) {
-      if (ev.which === ENTER_KEYCODE) {
+      if (ev.which == ENTER_KEYCODE) {
         filterValue = $filter.val();
         refillCarousel();
         ev.preventDefault();
@@ -197,7 +170,7 @@ $(function() {
 
     function handleError() {
       hideSpinner();
-      horizon.alert('error', gettext('Unable to run action.'));
+      horizon.alert('error', 'Unable to run action.');
     }
 
     bindActionHandlers($tab);
@@ -208,56 +181,54 @@ $(function() {
 
     function bindActionHandlers($parent) {
       $parent.find('.murano_action').off('click').on('click', function(event) {
-        var $this = $(this);
-        var $form = $this.closest('.table_wrapper > form');
-        var startUrl = $this.attr('href');
-        var resultUrl = null;
-        var ERRDATA = 'error';
-        var data = null;
-        function doRequest(url) {
-          var requestData;
-          $.ajax({
-            type: 'GET',
-            url: url,
-            async: false,
-            error: function () {
-              handleError();
-              requestData = ERRDATA;
-            },
-            success: function (newData) {
-              requestData = newData;
-            }
+        var $this = $(this),
+          $form = $this.closest('.table_wrapper > form'),
+          startUrl = $this.attr('href'),
+          resultUrl = null,
+          ERRDATA = 'error',
+          data = null;
+
+          horizon.modals.modal_spinner(gettext("Waiting for a result"));
+          button = '<div class="modal-close"' +
+            '><button class="btn btn-sm btn-danger" data-placement="right"' +
+            ' data-original-title="Action result won\'t be available">Stop Waiting</button></div>'
+          var modal_content = horizon.modals.spinner.find(".modal-content");
+          modal_content.append(button);
+          $('.modal-close button').tooltip();
+          $('.modal-close button').on("click", function () {
+            window.clearInterval(intervalId);
+            document.location = $form.attr('action');
           });
-          return requestData;
-        }
-
-        horizon.modals.modal_spinner(gettext("Waiting for a result"));
-        var button = '<div class="modal-close"' +
-          '><button class="btn btn-sm btn-danger" data-placement="right"' +
-          ' data-original-title="Action result won\'t be available">Stop Waiting</button></div>';
-        var modalContent = horizon.modals.spinner.find(".modal-content");
-        var intervalId;
-
-        modalContent.append(button);
-        $('.modal-close button').tooltip();
-        $('.modal-close button').on("click", function () {
-          window.clearInterval(intervalId);
-          document.location = $form.attr('action');
-        });
         if (startUrl) {
           $.ajax({
-            type: 'POST',
+            method: 'POST',
             url: startUrl,
             data: $form.serialize(),
             async: false,
-            success: function (successData) {
-              resultUrl = successData && successData.url;
+            success: function (data) {
+              resultUrl = data && data.url;
             },
             error: handleError
           });
-          if (resultUrl) {
+          if ( resultUrl ) {
+            function doRequest(url) {
+              var _data;
+              $.ajax({
+                method: 'GET',
+                url: url,
+                async: false,
+                error: function () {
+                  handleError();
+                  _data = ERRDATA;
+                },
+                success: function (newData) {
+                  _data = newData;
+                }
+              });
+              return _data;
+            }
 
-            intervalId = window.setInterval(function () {
+            var intervalId = window.setInterval(function () {
               // it's better to avoid placing the whole downloadable content
               // into JS memory in case of downloading very large files
               data = doRequest(resultUrl + 'poll');
@@ -267,10 +238,12 @@ $(function() {
                   if (data.isException) {
                     handleError();
                     document.location = resultUrl;
-                  } else if (typeof data.result !== "undefined" && data.result === null) {
+                  }
+                  else if (data.result !== undefined && data.result === null) {
                     hideSpinner();
                     document.location = $form.attr('action');
-                  } else {
+                  }
+                  else {
                     hideSpinner();
                     document.location = resultUrl;
                   }
@@ -281,6 +254,8 @@ $(function() {
         }
         event.preventDefault();
       });
-    }
+   }
+
   }
+
 });
